import argparse
from pathlib import Path

import pandas as pd
from sklearn.linear_model import LinearRegression


def process(args):
    # データを読み込み
    train_df = pd.read_csv(
        Path(args.in_dir) / "train.csv"
    )

    # 線形回帰
    lr = LinearRegression()
    X = train_df[["score_a", "score_b"]]
    y = train_df["score_c"]
    lr.fit(X, y)

    # 適用
    test_df = pd.read_csv(
        Path(args.in_dir) / "test.csv"
    )
    result = lr.predict(
        test_df[["score_a", "score_b"]]
    )

    # 結果をファイルに出力
    result_df = pd.DataFrame(
        {"name": test_df["name"], "score_c": result}
    )
    result_df.to_csv(
        Path(args.out_dir) / "result.csv",
        index=False,
    )
    print(result_df)


if __name__ == "__main__":
    # コマンドラインパラメータの登録
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-i",
        "--in_dir",
        type=str,
        help="入力ファイルを格納するディレクトリ",
    )
    parser.add_argument(
        "-o",
        "--out_dir",
        type=str,
        help="出力ファイルを格納するディレクトリ",
    )
    args = parser.parse_args()
    process(args)