from unittest import mock
from pathlib import Path

import pytest
import numpy as np


@pytest.fixture(autouse=True)
def setup_random_seed():
    """
    乱数によって結果が変わらないように
    シードを固定
    """
    np.random.seed(1)


@pytest.fixture()
def target():
    from samplecommand import process
    return process

    
@pytest.mark.parametrize(
    "case_name",
    ['case01']
)
def test_snapshot(
    target, tmpdir, snapshot, case_name
):
    """
    各ケースの入力値に対する出力値を
    スナップショットテストする
    """
    # arrange
    args = mock.Mock()
    args.in_dir = Path(
        'tests/test_snapshot/inputs'
    ) / case_name
    args.out_dir = tmpdir

    # act
    target(args)

    # assert
    with open(
        Path(tmpdir) / 'result.csv'
    ) as result:
        result_txt = result.read()
        snapshot.assert_match(
            result_txt, f'{case_name} result'
        )
